%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (c) Niky Riga                                                %
% WING group, Computer Science Department, Boston University   %
%                                                              %
% You can find full documentation and related information at:  %
% http://csr.bu.edu/dip/																			 %
%                                                              %
% To report your comment or any bug please send e-mail to:     %
% inki@cs.bu.edu                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function S = dip(S,num_slots,num_iter,r)
%
% Matlab implementation of                                      
% DIP : Density Inferense Protocol for Wireless Sensor Networks                                              
%	                                                              
                                         
%                                                               
%INPUT
%S is the matrix with the sensor information
%COLUMNS OF S
%1 = x (the x coordinate)
%2 = y (the y coordinate)
%3 = NOT USED
%4 = density of neighborhood
%5 = NOT USED
%6 = energy the amount of energy the sensor has left
%7 = NOT USED
%8 = the distance from the clusterhead, if a node is clusterhead then the
%    distance from the sink
%9 = sensed value;
%
%r : the range of transmission
%num_slots : times to repeat the first step to calculate the CW or the number of slots common to all the sensors
%num_iter : times to repeat the collision detection to calculate density
%
%OUTPUT
%S : the modified matrix with the sensor information
%
%PACKET SIZE		
%   18 PREAMBLE
%   2 SYNC
%   9 TOS MESSAGE
%       2 ADDRESS(BROADCAST ADDR)
%       1 TYPE
%       1 GROUPID
%       1 LENGTH(=2)
%       0 PAYLOAD
%       2 CRC

PACKET_SIZE = 27;

%Find the sensors that are still alive
live = find(S(:,6));
C = ones(size(live,1),1)*num_slots;

for i = 1 : num_iter
    [Z(i,:)] = find_distrib_slots(S,r,C);
end

%Assign to the 4th column the estimated density
m = mean(Z);
S(live,4) = round(log2((m')./num_slots)./log2(1-1/num_slots))./(pi*r^2);

%CALCULATE ENERGY
%all the nodes spend the same amount of energy
S(live,6) = S(live,6) - energy_tx(PACKET_SIZE	,r)*num_iter - energy_rx(PACKET_SIZE)*num_iter*(num_slots-1);
%if the sensors is negative that means that the sensor ran aout of energy during the execution of DIP so it has 0 energy left
t = find(S(:,6)<0);
S(t,6)=0;
