%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (c) Niky Riga                                                %
% WING group, Computer Science Department, Boston University   %
%                                                              %
% You can find full documentation and related information at:  %
% http://csr.bu.edu/dip/                            %
%                                                              %
% To report your comment or any bug please send e-mail to:     %
% inki@cs.bu.edu                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [K,K_ci,E_tx,E_rx]=estimate_num_neigh(S,r,num_slots,num_iter)
%this functions calculates how many neighbours each node has
%this function is implented for comparison reasons. 
%It is exactly the same function as DIP only with different
%output.
%
%INPUT
%S is the matrix with the sensor information
%COLUMNS OF S
%1 = x (the x coordinate)
%2 = y (the y coordinate)
%3 = NOT USED
%4 = density of neighborhood
%5 = NOT USED
%6 = energy the amount of energy the sensor has left
%7 = NOT USED
%8 = the distance from the clusterhead, if a node is clusterhead then the
%    distance from the sink
%9 = sensed value;e;
%
%r : the range of transmission
%num_slots : times to repeat the first step to calculate the CW or the number of slots common to all the sensors
%num_iter : times to repeat the collision detection to calculate density
%
%OUTPUT
%K 		:  the estimated number of neighburs
%K_ci 	: the confidence intervals
%E_tx : the enrgy spent for transimission 
%E_rx : the energy spent for recieving messages/idle listening
%
%PACKET SIZE		
%   18 PREAMBLE
%   2 SYNC
%   9 TOS MESSAGE
%       2 ADDRESS(BROADCAST ADDR)
%       1 TYPE
%       1 GROUPID
%       1 LENGTH(=2)
%       0 PAYLOAD
%       2 CRC

PACKET_SIZE = 27;

pl=1;
live = find(S(:,6));
C = ones(size(live,1),1)*num_slots;

for i = 1 : num_iter
    [Z(i,:)] = find_distrib_slots(S,r,C);
end
[K,K_ci] = mean2N(C,Z);

%CALCULATE ENERGY
E_tx = energy_tx(PACKET_SIZE	,r)*num_iter;

%listening slots : all the slots except the one transmitting
E_rx = energy_rx(PACKET_SIZE)*num_iter*(num_slots-1);