%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (c) Niky Riga                                                %
% WING group, Computer Science Department, Boston University   %
%                                                              %
% You can find full documentation and related information at:  %
% http://csr.bu.edu/dip/                            %
%                                                              %
% To report your comment or any bug please send e-mail to:     %
% inki@cs.bu.edu                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function Z =  find_silent_slots(S,D,tx,r)
%this function returns a vector of the sensors that observed a silent
%transmission 
%
%INPUT
%S is the matrix with the sensor information
%COLUMNS OF S
%1 = x (the x coordinate)
%2 = y (the y coordinate)
%3 = NOT USED
%4 = density of neighborhood
%5 = NOT USED
%6 = energy the amount of energy the sensor has left
%7 = NOT USED
%8 = the distance from the clusterhead, if a node is clusterhead then the
%    distance from the sink
%9 = sensed value;
%
%D : is a matrix with all the pairwise distances of sensors
%    (D(i,j)=dist(S(i),S(j))
%tx: tx is a matrix 1xM where M are the number of sensors that are alive
%    during this transmision. If tx(i)=1 then S(i) transmited this round
%    else it didn't
%NOTE tx should contain all nodes that are still ALIVE!!!!
%r : is the transmission range
%
%OUTPUT
%Z : a matrix that has 1 in the places that alive nodes witnessed a silence
%    slot

%line : the sensors that are still alive
[live] = find(S(:,6));
%dt : the pairwise distances of alive sensors
dt = D(live,live);
%make the columns of nodes that are not transmitting zero
dt(find(not(tx)),:) = 0;

%-r<dt-r<0 if dt<r and dt!=0
%(dt-r)./r>=-1
%(dt-r)./r+0.5>=-0.5
%round((dt-r)./r+0.5)=-1 if dt=0
%                    = 0 if 0<dt<=r hear the transmission!!!
%                    = 1 if dt>r
Z = sum(not(round((dt - r)./r + 0.5)));
Z = not(tx' + Z);