%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (c) Niky Riga                                                %
% WING group, Computer Science Department, Boston University   %
%                                                              %
% You can find full documentation and related information at:  %
% http://csr.bu.edu/dip/                           %
%                                                              %
% To report your comment or any bug please send e-mail to:     %
% inki@cs.bu.edu                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [C]=find_transmissions(S,D,tx,r)
%this function returns a vector of the sensors that observed successfull
%transmission 
%
%INPUT
%S is the matrix with the sensor information
%COLUMNS OF S
%1 = x (the x coordinate)
%2 = y (the y coordinate)
%3 = NOT USED
%4 = density of neighborhood
%5 = NOT USED
%6 = energy the amount of energy the sensor has left
%7 = NOT USED
%8 = the distance from the clusterhead, if a node is clusterhead then the
%    distance from the sink
%9 = sensed value;
%
%D : is a matrix with all the pairwise distances of sensors
%    (D(i,j)=dist(S(i),S(j))
%tx: tx is a matrix 1xM where M are the number of sensors that are alive
%    during this transmision. If tx(i)=1 then S(i) transmited this round
%    else it didn't
%NOTE tx should contain all nodes that are still ALIVE!!!!
%r : is the transmission range
%
%OUTPUT
%C : a matrix that has 1 in the places that alive nodes witnessed a
%    a successfull transmission

%live : the sensors that are still alive
[live] = find(S(:,6));

%the pairwise distances between the alive nodes
dt = D(live,live);
dt(find(not(tx)),:) = 0;
%0<dt-r<-r to negative if dt<r and dt!=0
%(dt-r)./r>=-1
%(dt-r)./r+0.5>=-0.5
%round((dt-r)./r+0.5)=-1 if dt=0
%                    = 0 if 0<dt<=r hear the transmission!!!
%                    = 1 if dt>r
%C : for each live sensor has the number of transmissions observed
C = sum(not(round((dt - r)./r + 0.5)));
%Add 1 to the sensors that transmitted
C = C + tx';
%Put a zero to all the sensors that witnessed collision
C(find(C>1)) = 0;
%Make the array a binary array
C=any(C);