%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (c) Niky Riga                                                %
% WING group, Computer Science Department, Boston University   %
%                                                              %
% You can find full documentation and related information at:  %
% http://csr.bu.edu/dip/                            %
%                                                              %
% To report your comment or any bug please send e-mail to:     %
% inki@cs.bu.edu                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function S=create_field_heavy_tail(a,gr_size,lambda)
%this function creates a field of sensors. the density follows a heavy tail
%distribution. it also initialies the struct S of the sensors.
%
%INPUT
%a is the side of the square
%gr_size is the size of eash grid where inside the desnsity is uniform
%
%OUTPUT
%S is a struct to keep the informations about the sensors
%COLUMNS OF S
%1 = x (the x coordinate)
%2 = y (the y coordinate)
%3 = the number of sensors in the same grid
%4 = type if 0 then sensor is just a node if 1 sensor is clusterhead
%5 = grid ID, the ID of the grid it belongs
%6 = energy the amount of energy the sensor has left
%7 = the time the sensor "died"
%8 = the distance from the clusterhead, if a node is clusterhead then the
%    distance from the sink
%9 = sensed value;

%if deb_fl=1 then plot is going to be geberated
deb_fl=0;

num_gr=floor(a/gr_size);
densities=assign_densities_heavy_tail(num_gr,lambda);
S=zeros(1,9);
for i=0 : num_gr - 1 
    for j=0 : num_gr - 1
        c=create_cluster_l(densities(i+1,j+1),gr_size);
        x_offset=i*gr_size;
        y_offset=j*gr_size;
        c(:,1)=c(:,1)+x_offset;
        c(:,2)=c(:,2)+y_offset;
        c(:,5)=c(:,5)+(i*10+j);
        c(:,8)=sqrt((c(:,1)-a/2).^2 + (c(:,2)-a/2).^2);
        S=cat(1,S,c);
    end  
end
S(1,:)=[];
S=assign_values(S,1);
if deb_fl
    plot_field(S);
end